@@ -4,7 +4,7 @@
 #       Massachusetts Institute of Technology.
 # written by Olivier Thereaux <ot@w3.org> for W3C
 #
-# $Id: Mail.pm,v 1.10 2004/09/10 00:41:24 ot Exp $
+# $Id: Mail.pm,v 1.5 2004/06/08 05:10:48 ot Exp $
 
 package W3C::LogValidator::Output::Mail;
 use strict;
@@ -15,7 +15,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
-our $VERSION = sprintf "%d.%03d",q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/;
+our $VERSION = '0.1';
 
 
 ###########################
@@ -58,20 +58,14 @@ sub finish
         {
                 my $result_string = shift;
 		my ($sec,$min,$hour,$day,$mon,$year,$wday,$yday) = gmtime(time);
-	        $hour = sprintf ( "%02d", $hour);
-		$min = sprintf ( "%02d", $min);
+	        my $hour = sprintf ( "%02d", $hour);
+		my $min = sprintf ( "%02d", $min);
 		$mon ++; # weird 'feature': months run 0-11; days run 1-31 :-(
 		my $date = ($year+1900) .'-'. ($mon>9 ? $mon:"0$mon") .'-'. ($day>9 ? $day:"0$day");
 
 		if (defined $config{"ServerAdmin"})
 		# we have someone to send the mail to
 		{
-			my $mail_subject = "Logvalidator results";
-			if (defined $config{"Title"})
-			{
-				$mail_subject = $config{"Title"};
-			}
-			$mail_subject = $mail_subject." ($date  $hour:$min GMT)";
 			my $add = $config{"ServerAdmin"};
 			my $mail_from = $add;
 			if (defined $config{"MailFrom"})
@@ -81,12 +75,11 @@ sub finish
 			use Mail::Sendmail;
 			my %mail = (To      => $add,
 			From    =>  "LogValidator <$mail_from>",
-			Subject => "$mail_subject",
+			Subject => "Logvalidator results : $date at $hour:$min GMT",
 			'X-Mailer' => "Mail::Sendmail version $Mail::Sendmail::VERSION",
 			Message => $result_string );
 			print "Sending Mail to $add...\n" if ($verbose >1 );
 			Mail::Sendmail::sendmail(%mail) or print STDERR $Mail::Sendmail::error;
-			if ($verbose >1 ) { print "OK Mail::Sendmail log:\n", $Mail::Sendmail::log, "\n";}
 		}
 		else { print $result_string; }
 	}
@@ -104,6 +97,9 @@ __END__
 
 W3C::LogValidator::Output::Mail - e-mail output module for the Log Validator
 
+=head1 SYNOPSIS
+
+
 =head1 DESCRIPTION
 
 This module is part of the W3C::LogValidator suite, and sends the results
